@@ -205,7 +205,8 @@ def correlation_heatmap(df,columns,minimum_size=-1,maximum_size=1,**kwargs):
     
 def Heatmap_Survey_group_difference(df,comparison_col_name,comparison_order,choice_col_name,category_col_name,category_order = None,
                                    minimum_size = 5,annot_loc = 10,annotate_dprime = True,annotate_mean_diffs = False,annotate_pvalue_significance = True,
-                                   output_diagnostics = False,significance_level = 0.05,footnote_x = 0, footnote_y = -0.5,footnote_size=13):
+                                   output_diagnostics = False,significance_level = 0.05,footnote_x = 0, footnote_y = -0.5,footnote_size=13,annotation_font_size=16,
+                                   ticks_font_size=20,custom_title = None, title_append = ''):
 
     '''
     This function is a heatmap of survey data representing response choices to a particular question. For each category, it
@@ -321,7 +322,11 @@ def Heatmap_Survey_group_difference(df,comparison_col_name,comparison_order,choi
     ax.set_xticklabels(ax.get_xmajorticklabels(), fontsize = 20,rotation=45)
     ax.set_xlabel(ax.get_xlabel(), fontsize = 20)
     ax.set_ylabel(ax.get_ylabel(), fontsize = 20)
-    ax.set_title('Proportion importance between {0} = {1} and {2} ({1}:{2})'.format(comparison_col_name,comparison_order[0],comparison_order[1]))
+    title = 'Proportion importance between {0} = {1} and {2} ({1}:{2})'.format(comparison_col_name,comparison_order[0],comparison_order[1])
+    if custom_title is not None:
+        title = custom_title
+    title = title + ' ' + title_append
+    ax.set_title(title)
     ax.set_yticklabels(ax.get_ymajorticklabels(), fontsize = 20,rotation=45)
 
     # Get axis labels and locations
@@ -367,10 +372,10 @@ def Heatmap_Survey_group_difference(df,comparison_col_name,comparison_order,choi
 
             if annotate_dprime:
                 if (pos1_len > minimum_size) and (pos2_len > minimum_size):
-                    plt.text(x=xtiks[ix] - (xtiks[1]-xtiks[0])/annot_loc,y=ytiks[iy], s='{}:{}'.format(int(np.round(scaledprop1*100,0)),int(np.round(scaledprop2*100,0))), fontsize=16)
+                    plt.text(x=xtiks[ix] - (xtiks[1]-xtiks[0])/annot_loc,y=ytiks[iy], s='{}:{}'.format(int(np.round(scaledprop1*100,0)),int(np.round(scaledprop2*100,0))), fontsize=annotation_font_size)
             elif annotate_mean_diffs:
                 if (pos1_len > minimum_size) and (pos2_len > minimum_size):
-                    plt.text(x=xtiks[ix] - (xtiks[1]-xtiks[0])/annot_loc,y=ytiks[iy], s='{}'.format(np.round(prop1-prop2,1)), fontsize=16)
+                    plt.text(x=xtiks[ix] - (xtiks[1]-xtiks[0])/annot_loc,y=ytiks[iy], s='{}'.format(np.round(prop1-prop2,1)), fontsize=annotation_font_size)
 
     t = 'Any cell not appearing has sample size < {0} for one of the groups\n'.format(minimum_size)
 
@@ -381,13 +386,13 @@ def Heatmap_Survey_group_difference(df,comparison_col_name,comparison_order,choi
         t = t + 'Pvalue: A * indicates significance between {0} groups at the {1} level'.format(comparison_col_name,significance_level)
 
 
-    a=fig.text(0,-0.5,t,size=13)
+    a=fig.text(footnote_x,footnote_y,t,size=footnote_size)
 
 
     cbar = ax.collections[0].colorbar
     ts = cbar.get_ticks()
     cbar.set_ticks(ts)
     cbar.set_ticklabels(['{}:{}'.format(100-int(i),int(i)) for i in ts])
-    cbar.ax.tick_params(labelsize=20)
+    cbar.ax.tick_params(labelsize=ticks_font_size)
     
     return fig
